@@ -2,12 +2,12 @@
 test_that("gps_as_sflinestring", {
   fortaleza <- read_gtfs(system.file("extdata/fortaleza.zip", package = "gtfs2gps"))
 
-  subset <- fortaleza %>%
-    gtfstools::filter_by_weekday(c("monday", "tuesday", "wednesday", "thursday", "friday")) %>%
-    filter_single_trip() %>%
+  subset <- fortaleza |>
+    gtfstools::filter_by_weekday(c("monday", "tuesday", "wednesday", "thursday", "friday")) |>
+    filter_single_trip() |>
     gtfstools::filter_by_shape_id(c("shape804-I", "shape806-I"))
   
-  for_gps <- gtfs2gps(subset) %>% adjust_speed()
+  for_gps <- gtfs2gps(subset) |> adjust_speed()
 
   for_gps_sf_lines <- gps_as_sflinestring(for_gps)
   for_gps_sf_lines
@@ -19,12 +19,11 @@ test_that("gps_as_sflinestring", {
   
   # -----
   # test to fix NA values
-  library(magrittr)
-  gps <- read_gtfs(system.file("extdata/poa.zip", package="gtfs2gps")) %>%
-    gtfstools::filter_by_shape_id(.,"176-1") %>% 
-    filter_single_trip() %>% 
-    gtfs2gps() %>% 
-    adjust_speed() %>% 
+  gps <- read_gtfs(system.file("extdata/poa.zip", package="gtfs2gps")) |>
+    gtfstools::filter_by_shape_id("176-1") |> 
+    filter_single_trip() |> 
+    gtfs2gps() |> 
+    adjust_speed() |> 
     gps_as_sflinestring()
   expect_equal(sum(units::drop_units(gps$cumtime)), 6248,tolerance = 0.1)
   
